@@ -3,8 +3,7 @@ PLSDA.ncomp <- function(X,Y,pred.method=c("mahalanobis.dist","centroids.dist","m
     stop(paste("you must update 'mixOmics' to version >= 5.0.2 (actual: ",
 	packageVersion("mixOmics"),")",sep=""))
   }
-  if (length(pred.method)!=1) {pred.method <- "mahalanobis.dist"}
-  if (!pred.method%in%c("max.dist","centroids.dist","mahalanobis.dist")) {stop("distance criterion not recognized")}
+  pred.method <- match.arg(pred.method)
   if (M<=1) {stop("invalid number of folds (must be > 1)")}
   ncolX <- ncol(X)
   model0 <- mixOmics::plsda(X,Y,ncomp=ncolX)
@@ -12,7 +11,7 @@ PLSDA.ncomp <- function(X,Y,pred.method=c("mahalanobis.dist","centroids.dist","m
   if ("try-error"%in%class(test)) {ncolX <- ncolX-1}
   model <- mixOmics::plsda(X,Y,ncomp=ncolX)
   val <- DA.valid(model,method="Mfold",crit.plsda=pred.method,M=M,nrep=nrep)
-  vars <- DA.var(model)
+  vars <- MVA.synt(model)
   opar <- par(no.readonly=TRUE)
   on.exit(par(opar))
   par(mar=c(5,4,2,5))
@@ -26,8 +25,8 @@ PLSDA.ncomp <- function(X,Y,pred.method=c("mahalanobis.dist","centroids.dist","m
   nlev <- nlevels(Y)
   abline(v=nlev-1,lty=3)
   segments(0,val$tab[nlev-1,1],nlev-1,val$tab[nlev-1,1],lty=3,col="red")
-  lines(1:ncolX,vars[,"Cumulative"],type="l",col="blue",lwd=2)
+  lines(1:ncolX,vars$tab[1:ncolX,"Cumulative"],type="l",col="blue",lwd=2)
   axis(4,col.axis="blue",col="blue")
   mtext("Proportion of intergroup variance explained (%)",side=4,line=2.5,col="blue",las=0)
-  segments(nlev-1,vars[nlev-1,"Cumulative"],ncolX,vars[nlev-1,"Cumulative"],lty=3,col="blue")
+  segments(nlev-1,vars$tab[nlev-1,"Cumulative"],ncolX,vars$tab[nlev-1,"Cumulative"],lty=3,col="blue")
 }
